Struct sbom_walker::discover::DiscoverConfig
source · pub struct DiscoverConfig {
pub source: String,
pub since: Option<SystemTime>,
pub keys: Vec<Key>,
}Expand description
Discovery configuration
Fields
source: StringThe URL to locate the provider metadata.
If full is true, this must be the full path to the provider-metadata.json, otherwise
it /.well-known/csaf/provider-metadata.json will be appended.
since: Option<SystemTime>Only report documents which have changed since the provided date. If a document has no
change information, or this field is None, it wil always be reported.
keys: Vec<Key>Keys which can be used for validation
Implementations
sourceimpl DiscoverConfig
impl DiscoverConfig
pub fn with_since(self, since: impl Into<Option<SystemTime>>) -> Self